;***********************************
;* Sony Infrared Keyboard Reader   *
;*                                 *
;* Ken Kaarvik    May21/99         *
;*                                 *
;***********************************

display_col		equ	$9809	;C	;980F
display_quantity	equ	11
text_line		equ	$9800+$20*16

	INCLUDE	"hardware.inc"
	INCLUDE	"ibmpc1.inc"

	SECTION "Header",HOME[$0100]

	nop
	jp	Startup

	DB	$CE,$ED,$66,$66,$CC,$0D,$00,$0B,$03,$73,$00,$83,$00,$0C,$00,$0D
	DB	$00,$08,$11,$1F,$88,$89,$00,$0E,$DC,$CC,$6E,$E6,$DD,$DD,$D9,$99
	DB	$BB,$BB,$67,$63,$6E,$0E,$EC,$CC,$DD,$DC,$99,$9F,$BB,$B9,$33,$3E

		;0123456789ABCDE
	DB	"Sony Keyboard  "
	DB	$80	;$80=Color GB
	DB	0,0,0	;SuperGameboy
	DB	0	;CARTTYPE
			;--------
			;0 - ROM ONLY
			;1 - ROM+MBC1
			;2 - ROM+MBC1+RAM
			;3 - ROM+MBC1+RAM+BATTERY
			;5 - ROM+MBC2
			;6 - ROM+MBC2+BATTERY

	DB	0	;ROMSIZE
			;-------
			;0 - 256 kBit ( 32 kByte,  2 banks)
			;1 - 512 kBit ( 64 kByte,  4 banks)
			;2 -   1 MBit (128 kByte,  8 banks)
			;3 -   2 MBit (256 kByte, 16 banks)
			;3 -   4 MBit (512 kByte, 32 banks)

	DB	0	;RAMSIZE
			;-------
			;0 - NONE
			;1 -  16 kBit ( 2 kByte, 1 bank )
			;2 -  64 kBit ( 8 kByte, 1 bank )
			;3 - 256 kBit (32 kByte, 4 banks)

	DW	$0000	;Manufacturer

	DB	0	;Version
	DB	0	;Complement check
	DW	0	;Checksum

	INCLUDE	"memory1.asm"

	SECTION	"Main",home[$0150]

Startup
	call	initialize

Main
	call	get_raw_signal

	call	convert_to_sony_value

	call	convert_to_ascii

	call	send_sony_out_Sout

	call	inc_counter

	;call	waitVB		;Do I really need this ???

	call	write_to_screen

	jp	Main

send_sony_out_Sout
	ld	a,[sony_ascii_value]
	ld	b,a
	ld	a,[sony_ascii_value_old]
	cp	b
	ret	z
	bit	7,a
	ret	z
	call	send_rs232
	ret

send_rs232			;send byte in B out Sout
	ld	e,8
	ld	a,0		;send start bit
	ldh	[$01],a
	ld	a,$83
	ldh	[$02],a
	call	delay_104us_send

send_next_bit
	rr	b
	ld	a,0
	jp	nc,keep_it_zero
	ld	a,$FF
keep_it_zero
	ldh	[$01],a
	ld	a,$83
	ldh	[$02],a
	call	delay_104us_send
	dec	e
	jp	nz,send_next_bit

	ld	a,$FF		;send stop bit
	ldh	[$01],a
	ld	a,$83
	ldh	[$02],a
	call	delay_104us_send

	ret

delay_130us
	ld	d,23
d130
	dec	d
	jp	nz,d130
	ret

delay_104us_send
	ld	d,16
d104s
	dec	d
	jp	nz,d104s
	ret


clear_sony_raw_ir
	xor	a
	ld	[sony_raw_ir],a
	ld	[sony_raw_ir+1],a
	ld	[sony_raw_ir+2],a
	ld	[sony_raw_ir+3],a
	ld	[sony_raw_ir+4],a
	ld	[sony_raw_ir+5],a
	ld	[sony_raw_ir+6],a
	ld	[sony_raw_ir+7],a

	ret

convert_to_sony_value

	ld	b,0
	ld	hl,sony_raw_ir
	ld	a,[hl]
	cp	$FF
	jp	nz,con1
	ld	b,a
	jp	end_convert_key_up

con1	ld	a,[hl+]		;measure mark

	call	divide_32	;divide by 32 return with
				;value in d
con2	scf
	rr	b
	jp	c,end_convert
	dec	d
	jp	nz,con2

	ld	a,[hl+]		;measure space
	call	divide_32
con3	scf
	ccf
	rr	b
	jp	c,end_convert
	dec	d
	jp	nz,con3

	jp	con1

end_convert
	ld	a,b
	and	$7F		;mask parity bit
end_convert_key_up
	ld	[sony_key_value],a

	ret

divide_32			;not quite divide by 32
	ld	d,1
	cp	$2D
	ret	c
	inc	d
	cp	$4D
	ret	c
	inc	d
	cp	$69
	ret	c
	inc	d
	cp	$87
	ret	c
	inc	d
	cp	$A5
	ret	c
	inc	d
	cp	$C3
	ret	c
	inc	d
	cp	$E1
	ret	c
	ret

;	srl	a		;divide by 32
;	srl	a
;	srl	a
;	srl	a
;	srl	a
;	inc	a
;	ld	d,a
;	ret

get_raw_signal				;And don't leave till
	call	clear_sony_raw_ir	;we get good data !!!
	ld	hl,sony_raw_ir
	ld	c,$56
	ld	b,2
	ld	d,0
wait_for_no_ir_start_again
	ld	d,200
wait_for_no_ir_new
	ld	a,[c]
	and	b
	jp	z,wait_for_no_ir_start_again
	dec	d			;wait NO IR signal
	jp	nz,wait_for_no_ir_new	;x256

wait_for_ir				;first pulse
	ld	a,[c]			;unmodulated ???
	and	b
	jp	nz,wait_for_ir

wait_for_no_ir
	ld	a,[c]
	and	b
	jp	z,wait_for_no_ir

wait_for_header
	ld	a,[c]
	and	b
	jp	nz,wait_for_header


call	count_mark		;count header

	ld	a,d		;valid header
	cp	$50		;between $50-$5C
	jp	c,get_error
	cp	$5C
	jp	nc,get_error

call	count_space		;count header space

	ld	a,d		;valid header space $1E
	cp	$1A		;between $1A-$22
	jp	c,get_error
	cp	$22
	jp	nc,get_error

call	count_mark		;second mark

	ld	a,d		;valid mark $1D
	cp	$1A		;between $1C-$22
	jp	c,get_error
	cp	$22
	jp	nc,get_error

call	count_space		;second space

	ld	a,d		;valid header space $1E
	cp	$1A		;between $1C-$22
	jp	c,get_error
	cp	$22
	jp	nc,get_error


call	count_mark		;3rd mark
				;could put some checking
				;here
				;If key press d=$39
				;If key release d=$1B


call	count_space		;3rd space
				;If key press d=$1E
				;If key release d=$80




	ld	a,d
	cp	$10
	jp	c,get_error
	cp	$40
	jp	nc,key_up

call	count_mark		;4th
				;d=$1D



call	count_space		;4th space  same to here
				;d=$1E

call	count_mark	;+0

	ld	a,d		;check for end
	cp	$10
	ret	c
	ld	[hl+],a

call	count_space	;+1

	ld	a,d
	cp	$10
	ret	c
	ld	[hl+],a

call	count_mark	;+2

	ld	a,d
	cp	$10
	ret	c
	ld	[hl+],a

call	count_space	;+3

	ld	a,d
	cp	$10
	ret	c
	ld	[hl+],a

call	count_mark	;+4

	ld	a,d
	cp	$10
	ret	c
	ld	[hl+],a

call	count_space	;+5

	ld	a,d
	cp	$10
	ret	c
	ld	[hl+],a

call	count_mark	;+6

	ld	a,d
	cp	$10
	ret	c
	ld	[hl+],a

call	count_space	;+7

	ld	a,d
	cp	$10
	ret	c
	ld	[hl+],a
	ret


key_up	ld	a,$FF
	ld	[sony_raw_ir],a
	ret

get_error
	jp	get_raw_signal

count_mark
	ld	d,0
count_mark_loop
	inc	d
cml	ld	a,[c]		;wait for current
	and	b		;pulse to go off
	jp	z,cml

	REPT	8
	ld	a,[c]
	and	b
	jp	z,count_mark_loop
	ENDR

	ret			;count in d


count_space
	ld	d,2
count_space_loop

	REPT	4		;fine tune count to
	ld	a,[c]		;match mark count
	and	b
	ret	z
	ENDR

	inc	d
	
	ret	z		;check for end of sequence
	jp	count_space_loop



inc_counter
	ld	a,[counter]
	inc	a
	ld	[counter],a
	ret

write_to_screen
	call	shift_display_up

	call	shift_display_left

	ld	de,counter
	ld	hl,display_col+9
	call	display_byte

	ld	de,sony_key_value	;DISPLAY HERE #######
	ld	hl,display_col+6
	call	display_byte

	ld	de,sony_ascii_value	;DISPLAY HERE #######
	ld	hl,display_col+3
	call	display_byte

	ld	a,[sony_ascii_value]	;DISPLAY HERE #######
	ld	hl,display_col
	call	display_char	;char

	ld	a,[sony_ascii_value]
	ld	hl,text_line
	call	display_char



	ld	hl,$9800
	ld	de,sony_raw_ir+7
	call	display_byte

	ld	hl,$9803
	ld	de,sony_raw_ir+6
	call	display_byte

	ld	hl,$9820
	ld	de,sony_raw_ir+5
	call	display_byte

	ld	hl,$9823
	ld	de,sony_raw_ir+4
	call	display_byte

	ld	hl,$9840
	ld	de,sony_raw_ir+3
	call	display_byte

	ld	hl,$9843
	ld	de,sony_raw_ir+2
	call	display_byte

	ld	hl,$9860
	ld	de,sony_raw_ir+1
	call	display_byte

	ld	hl,$9863
	ld	de,sony_raw_ir
	call	display_byte

	ld	hl,$98A3
	ld	de,sony_key_value
	call	display_byte

	ret

shift_display_left

	ld	a,[sony_ascii_value_old]
	ld	b,a
	ld	a,[sony_ascii_value]
	cp	b
	ret	z
	ld	[sony_ascii_value_old],a

	bit	7,a		;check for non print char
	ret	nz

	ld	hl,text_line+18
	ld	de,text_line+19
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+17
	ld	de,text_line+18
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+16
	ld	de,text_line+17
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+15
	ld	de,text_line+16
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+14
	ld	de,text_line+15
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+13
	ld	de,text_line+14
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+12
	ld	de,text_line+13
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+11
	ld	de,text_line+12
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+10
	ld	de,text_line+11
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+9
	ld	de,text_line+10
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+8
	ld	de,text_line+9
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+7
	ld	de,text_line+8
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+6
	ld	de,text_line+7
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+5
	ld	de,text_line+6
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+4
	ld	de,text_line+5
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+3
	ld	de,text_line+4
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+2
	ld	de,text_line+3
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line+1
	ld	de,text_line+2
	ld	bc,1
	call	mem_CopyVRAM

	ld	hl,text_line
	ld	de,text_line+1
	ld	bc,1
	call	mem_CopyVRAM

	ret

;shift_display_up

	ld	hl,display_col+$20*17	;copy from
	ld	de,display_col+$20*18	;copy to
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*16
	ld	de,display_col+$20*17
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*15
	ld	de,display_col+$20*16
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*14
	ld	de,display_col+$20*15
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*13
	ld	de,display_col+$20*14
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*12
	ld	de,display_col+$20*13
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*11
	ld	de,display_col+$20*12
	ld	bc,display_quantity
	call	mem_CopyVRAM
shift_display_up
	ld	hl,display_col+$20*10
	ld	de,display_col+$20*11
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*9
	ld	de,display_col+$20*10
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*8
	ld	de,display_col+$20*9
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*7
	ld	de,display_col+$20*8
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*6
	ld	de,display_col+$20*7
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*5
	ld	de,display_col+$20*6
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*4
	ld	de,display_col+$20*5
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+$20*3
	ld	de,display_col+$20*4
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+($20*2)
	ld	de,display_col+($20*3)
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+($20*1)
	ld	de,display_col+($20*2)
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ld	hl,display_col+($20*0)
	ld	de,display_col+($20*1)
	ld	bc,display_quantity
	call	mem_CopyVRAM

	ret

display_byte
	lcd_WaitVRAM
	ld	a,[de]
	ld	b,a
	and	$0F
	ld	[hl+],a
	lcd_WaitVRAM
	ld	a,b
	and	$F0
	swap	a
	ld	[hl],a
	ret

display_char
	bit	7,a		;don't look up non print chars
	ret	nz

	add	a,20		;add imb char offset
	push	af
	lcd_WaitVRAM
	pop	af
	ld	[hl],a
	ret

waitVB
	ldh	a,[$44]
	cp	144
	jp	nz,waitVB
	ret

initialize

.wait	ldh	a,[$44]		;LY LCDC compare
	cp	144
	jr	nc,.wait
	ld	a,0
	ldh	[$40],a		;LCDC lcd control

	ld	a,%10000000
	ldh	[$68],a		;BCPS
	ld	a,%00000000	;palette 0 0  bg
	ldh	[$69],a		;BCPD
	ld	a,%00000000
	ldh	[$69],a

	ld	a,%11111110	;palette 0 1
	ldh	[$69],a
	ld	a,%00011110
	ldh	[$69],a

	ld	a,%11111111	;palette 0 2  fg test font
	ldh	[$69],a
	ld	a,%01111111
	ldh	[$69],a

	ld	a,%11111111	;palette 0 3  fg ibm font
	ldh	[$69],a
	ld	a,%01111111
	ldh	[$69],a

	;ld	a,%00000000	;palette 1 0  bg
	;ldh	[$69],a
	;ld	a,%00000000
	;ldh	[$69],a

	ld	hl,Font		;load my test Font
	ld	de,$8000
	ld	bc,20*8*2
	call	mem_Copy

	ld	hl,ibm_characters	;load ibm font
	ld	de,$8000+20*8*2		;$8140
	ld	bc,8*128
	call	mem_CopyMono

	ld	a,1
	ldh	[$4F],a		;VBK
	ld	a,%01100000	;flip my screen
	ld	hl,$9800
	ld	bc,32*32
	call	mem_Set
	ld	a,0
	ldh	[$4F],a		;VBK


	ld	a,16		;blank char
	ld	hl,$9800
	ld	bc,20*32*32
	call	mem_Set

	ld	a,0
	ldh	[$42],a		;SCY Scroll Y
	ldh	[$43],a		;SCX Scroll X

	ld	a,%00000011
	ldh	[$47],a		;BGP

	ld	a,$00000000
	ldh	[$FF],a		;IE

	ld	a,%10010001
	ldh	[$40],a

	xor	a
	ld	[$FF24],a

	xor	a
	ld	[counter],a
	ld	[sony_raw_ir],a

	ld	a,%11000000
	ldh	[$56],a




	ret


convert_to_ascii
	ld	hl,sony_table
	ld	b,0
	ld	a,[sony_key_value]
	bit	7,a			;check for key up
	jp	nz,ascii_key_up
	ld	c,a	
	add	hl,bc
	ld	a,[hl]

	;ld	a,$55

	ld	[sony_ascii_value],a
	ret

ascii_key_up
	ld	a,$FF			;is $FF anyway but this is
	ld	[sony_ascii_value],a	;the code returned for key release
	ret

ibm_characters
	chr_IBMPC1	1,3

sony_table
	DB	$55	;U	$00
	DB	$4A	;J	01
	DB	$37	;7	02
	DB	$36	;6	03
	DB	$48	;H	04
	DB	$4D	;M	05
	DB	$59	;Y	06
	DB	$4E	;N	07
	DB	$49	;I	08
	DB	$4B	;K	09
	DB	$38	;8	0A
	DB	$3D	;=	0B
	DB	$00	;	0C
	DB	$2C	;,	0D
	DB	$5D	;]	0E
	DB	$00	;	0F
	DB	$50	;P	10
	DB	$3B	;;	11
	DB	$30	;0	12
	DB	$2D	;-	13
	DB	$60	;'	14
	DB	$	;	15
	DB	$5B	;[	16
	DB	$2F	;/	17
	DB	$4F	;O	18
	DB	$4C	;L	19
	DB	$39	;9	1A
	DB	$00	;Favs	1B
	DB	$00	;	1C
	DB	$2E	;.	1D
	DB	$00	;F7	1E
	DB	$00	;	1F
	DB	$00	;	20
	DB	$00	;	21
	DB	$00	;Find	22
	DB	$00	;Recent	23
	DB	$00	;ScrollD24
	DB	$00	;	25
	DB	$00	;	26
	DB	$00	;ArrowR	27
	DB	$00	;	28
	DB	$00	;ScrollU29
	DB	$00	;Mail	2A
	DB	$00	;Option	2B
	DB	$00	;	2C
	DB	$00	;Info	2D
	DB	$00	;	2E
	DB	$00	;ArrowD	2F
	DB	$00	;	30
	DB	$00	;Back	31
	DB	$00	;	32
	DB	$00	;Edit	33
	DB	$00	;ArrowU	34
	DB	$00	;Send	35
	DB	$00	;	36
	DB	$00	;ArrowL	37
	DB	$00	;	38
	DB	$00	;Fn	39
	DB	$00	;	3A
	DB	$00	;	3B
	DB	$00	;	3C
	DB	$00	;	3D
	DB	$00	;	3E
	DB	$00	;	3F
	DB	$00	;	40
	DB	$5C	;\	41
	DB	$00	;Search	42
	DB	$00	;Home	43
	DB	$00	;F6	44
	DB	$13	;Return	45
	DB	$7F	;Delete	46
	DB	$20	;SPACE	47
	DB	$00	;CH+	48
	DB	$00	;CH-	49
	DB	$00	;	4A
	DB	$00	;	4B
	DB	$00	;	4C
	DB	$00	;RShift	4D	*****
	DB	$00	;LShift	4E	*****
	DB	$00	;	4F
	DB	$00	;Save	50
	DB	$00	;	51
	DB	$00	;Goto	52
	DB	$00	;	53
	DB	$00	;Ctrl	54	*****
	DB	$00	;	55
	DB	$1B	;Esc	56
	DB	$00	;R Alt	57	*****
	DB	$52	;R	58
	DB	$46	;F	59
	DB	$34	;4	5A
	DB	$35	;5	5B
	DB	$47	;G	5C
	DB	$56	;V	5D
	DB	$54	;T	5E
	DB	$42	;B	5F
	DB	$51	;Q	60
	DB	$41	;A	61
	DB	$31	;1	62
	DB	$00	;Cmd	63	*****
	DB	$00	;Power	64	web
	DB	$5A	;Z	65
	DB	$00	;Tab	66	*****
	DB	$00	;L Alt	67	*****
	DB	$45	;E	68
	DB	$44	;D	69
	DB	$33	;3	6A
	DB	$00	;F2	6B
	DB	$00	;F4	6C
	DB	$43	;C	6D
	DB	$00	;F3	6E
	DB	$00	;	6F
	DB	$57	;W	70
	DB	$53	;S	71
	DB	$32	;2	72
	DB	$00	;F1	73
	DB	$00	;F5	74
	DB	$58	;X	75
	DB	$00	;Caps	76	*****
	DB	$00	;	77
	DB	$00	;	78
	DB	$00	;	79
	DB	$00	;View	7A
	DB	$00	;`	7B
	DB	$00	;	7C
	DB	$00	;	7D
	DB	$00	;	7E
	DB	$25	;	7F
Font:
	DW	`01111100
	DW	`10000010
	DW	`10000010
	DW	`10000010
	DW	`10000010
	DW	`10000010
	DW	`01111100
	DW	`00000000

	DW	`00010000
	DW	`00110000
	DW	`00010000
	DW	`00010000
	DW	`00010000
	DW	`00010000
	DW	`00111000
	DW	`00000000

	DW	`01111100
	DW	`10000010
	DW	`00000010
	DW	`01111100
	DW	`10000000
	DW	`10000000
	DW	`11111110
	DW	`00000000

	DW	`01111100
	DW	`10000010
	DW	`00000010
	DW	`00011100
	DW	`00000010
	DW	`10000010
	DW	`01111100
	DW	`00000000

	DW	`00001100
	DW	`00010100
	DW	`00100100
	DW	`01000100
	DW	`11111110
	DW	`00000100
	DW	`00000100
	DW	`00000000

	DW	`11111110
	DW	`10000000
	DW	`10000000
	DW	`11111100
	DW	`00000010
	DW	`00000010
	DW	`11111100
	DW	`00000000

	DW	`01111100
	DW	`10000000
	DW	`10000000
	DW	`11111100
	DW	`10000010
	DW	`10000010
	DW	`01111100
	DW	`00000000

	DW	`11111110
	DW	`00000010
	DW	`00000100
	DW	`00001000
	DW	`00010000
	DW	`00010000
	DW	`00010000
	DW	`00000000

	DW	`01111100
	DW	`10000010
	DW	`10000010
	DW	`01111100
	DW	`10000010
	DW	`10000010
	DW	`01111100
	DW	`00000000

	DW	`01111100
	DW	`10000010
	DW	`10000010
	DW	`01111110
	DW	`00000010
	DW	`00000010
	DW	`01111100
	DW	`00000000

	DW	`00111000
	DW	`01000100
	DW	`10000010
	DW	`11111110
	DW	`10000010
	DW	`10000010
	DW	`10000010
	DW	`00000000

	DW	`11111100
	DW	`10000010
	DW	`10000010
	DW	`11111100
	DW	`10000010
	DW	`10000010
	DW	`11111100
	DW	`00000000

	DW	`00111100
	DW	`01000010
	DW	`10000000
	DW	`10000000
	DW	`10000000
	DW	`01000010
	DW	`00111100
	DW	`00000000

	DW	`11111000
	DW	`10000100
	DW	`10000010
	DW	`10000010
	DW	`10000010
	DW	`10000100
	DW	`11111000
	DW	`00000000

	DW	`11111110
	DW	`10000000
	DW	`10000000
	DW	`11111000
	DW	`10000000
	DW	`10000000
	DW	`11111110
	DW	`00000000

	DW	`11111110
	DW	`10000000
	DW	`10000000
	DW	`11111000
	DW	`10000000
	DW	`10000000
	DW	`10000000
	DW	`00000000

	DW	`00000000	;16
	DW	`00000000
	DW	`00000000
	DW	`00000000
	DW	`00000000
	DW	`00000000
	DW	`00000000
	DW	`00000000

	DW	`11111111	;17 web mark
	DW	`10000001
	DW	`00000000
	DW	`00000000
	DW	`00000000
	DW	`00000000
	DW	`00000000
	DW	`00000000

	DW	`00000000	;18 web space
	DW	`00000000
	DW	`00000000
	DW	`00000000
	DW	`00000000
	DW	`10000001
	DW	`11111111
	DW	`00000000

	DW	`11111100	;19
	DW	`10000010	;P for parity
	DW	`10000010
	DW	`11111100
	DW	`10000000
	DW	`10000000
	DW	`10000000
	DW	`00000000


	SECTION	"GB_ram",BSS
counter			DS	1
sony_key_value		DS	1
sony_ascii_value	DS	1
sony_ascii_value_old	DS	1
sony_char_value		DS	1
sony_raw_ir		DS	8